==> appfs-21.02.tar.gz: home/admin/conf/rootfs/pkg/recoverygui/usr/www/cgi-bin/reboot.php <==
<?php

include('/usr/www/include/berogui_small.class.php');
include_once("/usr/www/include/SQLite2ToSQLite3.php");
include('/usr/fallback/beroConf.php');

$bc = new beroConf('root');
require_once('/usr/www/include/redirect_fwupdate.php');

$gui = new berogui_small('beroNet VoIP Gateway: Reboot');

$requireFwUpdate = (0 || $bc->get('root', 'appfs-reset') == 1 || $bc->get('root', 'rootfs-reset') == 1 || $bc->get('root', 'userappfs-reset') == 1);

echo	$gui->header() .
	'<div style="text-align: center;">' . "\n";

if ($requireFwUpdate) {
	echo 	"<h3>Firmware Installation required</h3>\n"
			.	"The Appfs-Space or Rootfs-Space has been reset. A new firmware installation is required for full stability of the Gateway.<br/>\n"
			. "Please do a firmware update before you reboot";
}
else if (file_exists('/var/run/install_daemon.pid')) {
	echo	'<h3>Rebooting disabled</h3>' . "\n" .
		'An Installation is in progress. Please wait until it is completed and reboot the Gateway afterwards.' . "\n";
} else if ($_GET['action'] == 'do_reboot') {
        echo    '<script type="text/javascript">window.setTimeout("setRequest()",10000);</script>' . "\n" .
		'<h3>Rebooting</h3>' . "\n" .
		'Please wait until you will be redirected to the login-page or click <a href="/">here</a> to login.<br />' . "\n";
}
else if ($_POST['action'] == 'restore') {
	$_GET = $_POST;
	echo 	"<script type='text/javascript'>window.setTimeout('setRequest()',20000);</script>\n"
			.	"<h3>Restoring And Rebooting</h3>\n"
			. "Please wait until you will be redirected to the login-page or click <a href='/'>here</a> to login.<br/>\n";
}
else {
	echo	'<h3>Reboot Gateway</h3>' . "\n" .
		'This will reboot the Gateway in normal mode and restart all services.<br />' ."\n" .
		'<h4 style="margin-bottom: 2px;">Are you sure that you want to reboot the Gateway now?</h4>' . "\n" .
		'(This may take several minutes, please only click once.)<br /><br />' . "\n" .
		'<span style="font-weight: bold; word-spacing: 20px;"><a href="/cgi-bin/reboot.php?action=do_reboot">Yes</a> <a href="/">No</a></span>' . "\n";
}

echo	'</div>' . "\n" .
	$gui->footer('reboot');

if ($requireFwUpdate) {
	exit(0);
}

if (!file_exists('/var/run/install_daemon.pid') && in_array($_GET['action'], array('do_reboot', 'restore'))) {
	if ($bc->get('root', 'boot_fwupdate') == '1') {
		$bc->set('root', 'boot_fwupdate', '0');
	}
	else if ($bc->get('root', 'boot_recoverymode') == '1') {
		$bc->set('root', 'boot_recoverymode', '0');
	}
	if ($_GET['action'] == 'restore') {
		unlink('/tmp/has_activity');
		exec('/usr/sbin/recovery-mode.sh >/dev/null 2>&1 &');
		exit(0);
	}
	sleep(1);
	exec('/sbin/reboot >/dev/null 2>&1 &');
}

?>

==> appfs-24.01.01-rc45.tar.gz: home/admin/conf/rootfs/pkg/recoverygui/usr/www/cgi-bin/reboot.php <==
<?php

include('/usr/www/include/berogui_small.class.php');
include_once("/usr/www/include/SQLite2ToSQLite3.php");
include('/usr/fallback/beroConf.php');

$bc = new beroConf('root');
require_once('/usr/www/include/redirect_fwupdate.php');

$gui = new berogui_small('beroNet SBC / VoIP Gateway: Reboot');

$requireFwUpdate = (0 || $bc->get('root', 'appfs-reset') == 1 || $bc->get('root', 'rootfs-reset') == 1 || $bc->get('root', 'userappfs-reset') == 1);

echo	$gui->header() .
	'<div style="text-align: center;">' . "\n";

if (strlen($bc->get('root', 'TLSv1.2-disabled'))) {
	## do nothing. avoid to reboot
}
else if ($requireFwUpdate) {
	echo 	"<h3>Firmware Installation required</h3>\n"
			.	"The Appfs-Space or Rootfs-Space has been reset. A new firmware installation is required for full stability of the Gateway.<br/>\n"
			. "Please do a firmware update before you reboot";
}
else if (file_exists('/var/run/install_daemon.pid')) {
	echo	'<h3>Rebooting disabled</h3>' . "\n" .
		'An Installation is in progress. Please wait until it is completed and reboot the Gateway afterwards.' . "\n";
} else if ($_GET['action'] == 'do_reboot') {
        echo    '<script type="text/javascript">window.setTimeout("setRequest()",10000);</script>' . "\n" .
		'<h3>Rebooting</h3>' . "\n" .
		'Please wait until you will be redirected to the login-page or click <a href="/">here</a> to login.<br />' . "\n";
}
else if ($_POST['action'] == 'restore') {
	$_GET = $_POST;
	echo 	"<script type='text/javascript'>window.setTimeout('setRequest()',20000);</script>\n"
			.	"<h3>Restoring And Rebooting</h3>\n"
			. "Please wait until you will be redirected to the login-page or click <a href='/'>here</a> to login.<br/>\n";
}
else {
	echo	'<h3>Reboot Gateway</h3>' . "\n" .
		'This will reboot the Gateway in normal mode and restart all services.<br />' ."\n" .
		'<h4 style="margin-bottom: 2px;">Are you sure that you want to reboot the Gateway now?</h4>' . "\n" .
		'(This may take several minutes, please only click once.)<br /><br />' . "\n" .
		'<span style="font-weight: bold; word-spacing: 20px;"><a href="/cgi-bin/reboot.php?action=do_reboot">Yes</a> <a href="/">No</a></span>' . "\n";
}

echo	'</div>' . "\n" .
	$gui->footer('reboot');

if ($requireFwUpdate) {
	exit(0);
}

if (!file_exists('/var/run/install_daemon.pid') && in_array($_GET['action'], array('do_reboot', 'restore'))) {
	if ($bc->get('root', 'boot_fwupdate') == '1') {
		$bc->set('root', 'boot_fwupdate', '0');
	}
	else if ($bc->get('root', 'boot_recoverymode') == '1') {
		$bc->set('root', 'boot_recoverymode', '0');
	}
	if ($_GET['action'] == 'restore') {
		unlink('/tmp/has_activity');
		exec('/usr/sbin/recovery-mode.sh force >/dev/null 2>&1 &');
		exit(0);
	}
	sleep(1);
	exec('/sbin/reboot >/dev/null 2>&1 &');
}

?>
